<?php
global $span_theme_option_namespace;
span_opt_topbar( $span_theme_option_namespace );

span_opt_header( $span_theme_option_namespace );

span_opt_footer( $span_theme_option_namespace );

span_opt_layout( $span_theme_option_namespace );

span_opt_sidebar( $span_theme_option_namespace );

span_opt_pheader( $span_theme_option_namespace );

if( in_array( $span_theme_option_namespace, array( 'blog', 'archives', 'authors', 'search' ) ) ) {
	span_opt_post( $span_theme_option_namespace );
}